OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Erreur lors de l'analyse du fichier journal",
    "Copy" : "Copier",
    "Copy raw" : "Copie brute",
    "Copy formatted" : "Copie formatée",
    "No server logs" : "Aucun journal serveur",
    "One or more entries are hidden by the log level filter" : "Des entrées sont masquées par le filtre sur le niveau de journalisation",
    "Everything is working fine" : "Tout fonctionne à merveille",
    "Level" : "Niveau",
    "App" : "App",
    "Message" : "Message",
    "Time" : "Heure",
    "Log levels" : "Niveaux du registre",
    "Log content" : "Contenu du registre",
    "Live update" : "Mise à jour en direct",
    "Download logs" : "Télécharger les journaux",
    "Logging" : "Journalisation",
    "Log Reader" : "Lecteur du fichier journal",
    "A log reader for Nextcloud" : "Un lecteur du fichier journal pour Nextcloud",
    "Log reader for Nextcloud" : "Lecteur du fichier journal pour Nextcloud",
    "Cased by " : "Enveloppé par"
},
"nplurals=2; plural=(n > 1);");
